@@ -53,6 +53,7 @@ class Teacher(cfg.ConfigUtils, QstatusDefs):
         # The file name, not a file object
         self.m_lessonfile = None
         self.m_question = None
+        self.m_custom_mode = False
     def maybe_auto_new_question(self):
         if self.get_bool('new_question_automatically'):
             if self.m_timeout_handle is None:
@@ -97,7 +98,7 @@ class Teacher(cfg.ConfigUtils, QstatusDefs):
 """There was an IOError while trying to parse a lesson file:
 %s.""" % e)
             return
-        if [q for q in self.m_P.m_questions if isinstance(q['music'], lessonfile.Cmdline)]:
+        if [q for q in self.m_P.m_questions if isinstance(q.get('music'), lessonfile.Cmdline)]:
             run = gu.dialog_yesno(_("The lessonfile contain potentially dangerous code because it run external programs. Run anyway?"))
             if not run:
                 self.m_P = None
@@ -272,14 +273,14 @@ class RhythmAddOnClass:
         Return a complete mpd string of the current question that can
         be feed to utils.play_music.
         """
-        return r"\staff{%s}" % self.get_music_notenames(True)
+        return r"\rhythmstaff{%s}" % self.get_music_notenames(True)
     def play_rhythm(self, rhythm):
         """
         rhythm is a string. Example: 'c4 c8 c8 c4'
         """
         # FIXME can we use lessonfile.Rhythm insted of this?
         score = mpd.parser.parse_to_score_object(rhythm)
-        track = mpd.score_to_percussion_tracks(score)[0]
+        track = mpd.score_to_tracks(score)[0]
         track.prepend_bpm(self.get_int("bpm"))
         track.prepend_volume(cfg.get_int('config/preferred_instrument_volume'))
         track.replace_note(mpd.notename_to_int("c"),
@@ -317,7 +318,6 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
          - practise_box
          - action_area
          - config_box
-    
     """
     short_delay=700
     def __init__(self, teacher, no_notebook=False):
@@ -486,7 +486,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
                         name = name.split('-')[0]
                     getattr(self, 'g_%s' % name).hide()
     def std_buttons_answer_correct(self):
-        # Setting sensitivity is only required when 
+        # Setting sensitivity is only required when
         # self.get_bool('config/picky_on_new_question') is True, but
         # we does it every time just in case the user have changed the
         # variable between clicking 'New' and answering the question.
